import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * A rock in space
 * 
 * @author Poul Henriksen
 */
public class Asteroid extends MovingThing
{
    /** Size of this asteroid */
    private int size;
    /** Whether is is exploded */
    private boolean exploded = false;
    /** When the health reaches 0 the asteroid will explode*/
    private int health;

    
    public Asteroid()
    {
        this(64);
    }
    
    public Asteroid(int size)
    {
        super(2);
        setSize(size);
    }
    
    public Asteroid(int size, double speedx, double speedy)
    {
        super(speedx, speedy);
        setSize(size);
    }
    
    public void act()
    {         
        if(exploded) return;
        moveAtSpeed();
    }

    public void setSize(int size) {
        health = size;
        this.size = size;
        GreenfootImage image = new GreenfootImage("rock.gif");
        image.scale(size, size);
        setImage(image);
    }
    
    /**
     * Explodes this asteroid into two smaller asteroids
     */
    private void explode() {
        if (exploded)
        {
            // Don't explode twice!
            return;
        }
        exploded = true;
                
        //Greenfoot.playSound("Explosion.wav");
        
        if(size <= 16) {
            getWorld().removeObject(this);
            return;
        }

        Asteroid a1 = new Asteroid(size/2, getSpeedX() + Greenfoot.getRandomNumber(2), getSpeedY() + Greenfoot.getRandomNumber(2));        
        Asteroid a2 = new Asteroid(size/2, getSpeedX() + Greenfoot.getRandomNumber(2), getSpeedY() + Greenfoot.getRandomNumber(2));
        getWorld().addObject(a1, getX(), getY());
        getWorld().addObject(a2, getX(), getY());        
        a1.moveAtSpeed();
        a2.moveAtSpeed();
    
        getWorld().removeObject(this);
    }
    
    /**
     * Hit this asteroid dealing the given amount of damage.
     */
    public boolean hit(int damage) {
        if (exploded)
        {
            return false;
        }
        health = health - damage;
        if(health <= 0) 
        {
            explode();         
            return true;
        }
        return false;
    }
}